URL_API = 'https://api.openweathermap.org/data/2.5/'

# Options to take wetaher
CURRENT = 'weather?'
FORECAST = 'forecast?'

LANGCODES = {
    'af': 'Afrikaans',
    'al': 'Albanian',
    'ar': 'Arabic',
    'az': 'Azerbaijani',
    'bg': 'Bulgarian',
    'ca': 'Catalan',
    'cz': 'Czech',
    'da': 'Danish',
    'de': 'German',
    'el': 'Greek',
    'en': 'English',
    'eu': 'Basque',
    'fa': 'Persian (Farsi)',
    'fi': 'Finnish',
    'fr': 'French',
    'gl': 'Galician',
    'he': 'Hebrew',
    'hi': 'Hindi',
    'hr': 'Croatian',
    'hu': 'Hungarian',
    'id': 'Indonesian',
    'it': 'Italian',
    'ja': 'Japanese',
    'kr': 'Korean',
    'la': 'Latvian',
    'lt': 'Lithuanian',
    'mk': 'Macedonian',
    'no': 'Norwegian',
    'nl': 'Dutch',
    'pl': 'Polish',
    'pt': 'Portuguese',
    'pt_br': 'Português Brasil',
    'ro': 'Romanian',
    'ru': 'Russian',
    'sv': 'Swedish',
    'sk': 'Slovak',
    'sl': 'Slovenian',
    'es': 'Spanish',
    'sr': 'Serbian',
    'th': 'Thai',
    'tr': 'Turkish',
    'uk': 'Ukrainian',
    'vi': 'Vietnamese',
    'zh_cn': 'Chinese Simplified',
    'zhtw':  'Chinese Traditional',
    'zu': 'Zulu'
}
